@@ -468,7 +468,7 @@ class CompleteSummarizationPipeline:
         from datetime import datetime
 
         try:
-          with open(output_json, "r") as f:
+          with open("hotels.json", "r") as f:
             data = json.load(f)
         except (FileNotFoundError, json.JSONDecodeError):
           data = {}  # keep root as dict
@@ -476,5 +476,5 @@ class CompleteSummarizationPipeline:
         timestamp = datetime.now().isoformat()
         data[timestamp] = best_summary_data  # store under unique key
 
-        with open(output_json, "w") as f:
+        with open("hotels.json", "w") as f:
           json.dump(data, f, indent=4)
\ No newline at end of file
